@@ -38,7 +38,7 @@ def list_dict_group(data: List[Dict], key):
     :return:
     """
     new_data = {"list_data": list(), "dict_data": dict()}
-    data.sort(key=lambda x: x.get(key, ""))
+    data.sort(key=lambda x: x.get(key, "") or "")
     group_data = groupby(data, key=lambda x: x.get(key, ""))
     for data_key, values in group_data:
         _values = list(values)
